Method: OpenLoad#upload_link
- Defined in:
- lib/openload.rb
#upload_link(folder = nil, sha1 = nil, httponly = nil) ⇒ Object
This method return a link that you can make uploads. Warning: this links expire in a few hours, always check the .
40 41 42 |
# File 'lib/openload.rb', line 40 def upload_link(folder = nil, sha1 = nil, httponly = nil) get_a_request_and_return_in_a_struct("/file/ul#{login_parameter(true)}#{key_parameter}#{http_parameter('folder', folder)}#{http_parameter('sha1', sha1)}#{http_parameter('httponly', httponly)}") end |